==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/da.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH.mm.ss",
    Ed => "E 'den' d.",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "M",
    MEd => "E d.M",
    MMM => "MMM",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-one" => "W. 'uge' 'i' MMMM",
    "MMMMW-count-other" => "W. 'uge' 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "dd.MM",
    Md => "d.M",
    d => "d.",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss a v",
    hmv => "h.mm a v",
    ms => "mm.ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uge' w 'i' Y",
    "yw-count-other" => "'uge' w 'i' Y",
  },
  code => "da",
  date_format_full => "EEEE 'den' d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} 'kl'. {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "man",
    "tir",
    "ons",
    "tor",
    "fre",
    "l\N{U+00f8}r",
    "s\N{U+00f8}n",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "fKr",
    "eKr",
  ],
  era_wide => [
    "f.Kr.",
    "e.Kr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Danish",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "marts",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "marts",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "december",
  ],
  name => "Danish",
  native_language => "dansk",
  native_name => "dansk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. kvt.",
    "2. kvt.",
    "3. kvt.",
    "4. kvt.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "1. kvt.",
    "2. kvt.",
    "3. kvt.",
    "4. kvt.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH.mm.ss zzzz",
  time_format_long => "HH.mm.ss z",
  time_format_medium => "HH.mm.ss",
  time_format_short => "HH.mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/da.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH.mm.ss",
    Ed => "E 'den' d.",
    Ehm => "E h.mm\N{U+202f}a",
    Ehms => "E h.mm.ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "M",
    MEd => "E d.M",
    MMM => "MMM",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-one" => "W. 'uge' 'i' MMMM",
    "MMMMW-count-other" => "W. 'uge' 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "dd.MM",
    Md => "d.M",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h.mm\N{U+202f}a",
    hms => "h.mm.ss\N{U+202f}a",
    hmsv => "h.mm.ss\N{U+202f}a v",
    hmv => "h.mm\N{U+202f}a v",
    ms => "mm.ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uge' w 'i' Y",
    "yw-count-other" => "'uge' w 'i' Y",
  },
  code => "da",
  date_format_full => "EEEE 'den' d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "man.",
    "tirs.",
    "ons.",
    "tors.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "man.",
    "tirs.",
    "ons.",
    "tors.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "fKr",
    "eKr",
  ],
  era_wide => [
    "f\N{U+00f8}r Kristus",
    "efter Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Danish",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "marts",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "maj",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "marts",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "december",
  ],
  name => "Danish",
  native_language => "dansk",
  native_name => "dansk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. kvt.",
    "2. kvt.",
    "3. kvt.",
    "4. kvt.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "1. kvt.",
    "2. kvt.",
    "3. kvt.",
    "4. kvt.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH.mm.ss zzzz",
  time_format_long => "HH.mm.ss z",
  time_format_medium => "HH.mm.ss",
  time_format_short => "HH.mm",
  variant => undef,
  version => "44.1",
}
